package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.ZhxyShyj;

/**
 * 智慧校园_审核意见Mapper接口
 *
 * @author ruoyi
 * @date 2023-05-30
 */
public interface ZhxyShyjMapper
{
    /**
     * 查询智慧校园_审核意见
     *
     * @param id 智慧校园_审核意见主键
     * @return 智慧校园_审核意见
     */
    public ZhxyShyj selectZhxyShyjById(Long id);

    /**
     * 查询智慧校园_审核意见列表
     *
     * @param zhxyShyj 智慧校园_审核意见
     * @return 智慧校园_审核意见集合
     */
    public List<ZhxyShyj> selectZhxyShyjList(ZhxyShyj zhxyShyj);

    /**
     * 新增智慧校园_审核意见
     *
     * @param zhxyShyj 智慧校园_审核意见
     * @return 结果
     */
    public int insertZhxyShyj(ZhxyShyj zhxyShyj);

    /**
     * 修改智慧校园_审核意见
     *
     * @param zhxyShyj 智慧校园_审核意见
     * @return 结果
     */
    public int updateZhxyShyj(ZhxyShyj zhxyShyj);

    /**
     * 删除智慧校园_审核意见
     *
     * @param id 智慧校园_审核意见主键
     * @return 结果
     */
    public int deleteZhxyShyjById(Long id);

    /**
     * 批量删除智慧校园_审核意见
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZhxyShyjByIds(Long[] ids);
}
